"""
Identifier:     KSC-SJ6-csst_ifs_common/common.py
Name:           Common.py
Description:    CSST IFS COMMON
Author:         Wei Chen
"""

from .ifs_status import CsstIFSStatus
from .exit_code_list import IFSExitCode
from .logger import get_logger
# from .ifs_status import IFSError
from .config import IFSConfig
import os


class CsstIFSInit:

    def __init__(self):
        self.exit_code = "100"
        self.status = CsstIFSStatus
        self.fun_exit_code = IFSExitCode()
        self._env_init()
        self._dm_init()
        self.config_ifs_rss_env()
        self.config_ifs_cube_env()
        self.logger = get_logger()

    def _env_init(self):
        # code 100: "l1 normal exit"
        exit_code = "100"
        # self.logger.info("IFS Env Setting...")
        try:
            self.config = IFSConfig()
            self.config.set_ifs_config("dir_log", self.config.get_ifs_config("dir_local"))
            path_log = os.path.join(self.config.get_ifs_config("dir_log"), "./log.txt")
            self.config.set_ifs_config("path_log", path_log)
            self.logger = get_logger("CSST IFS log", self.config.get_ifs_config("path_log"))
            # self.logger.info("IFS Env Set Finish!")
        except Exception as e:
            # code 101: "l1 Env Set Error",
            exit_code = "101"
            print("{}".format(e))
            self.logger.error(self.fun_exit_code.get_ifs_exit_code('101'))
            self.logger.error(e)
            status = 2
            assert status in [CsstIFSStatus.PERFECT, CsstIFSStatus.WARNING]
        finally:
            return exit_code

    def _dm_init(self):
        # code 100: "l1 normal exit"
        exit_code = "100"
        try:
            from .data_manager import CsstIFSDataManager
            self.dm = CsstIFSDataManager()
        except Exception as e:
            # code 102: "Not found DFS system",
            # exit_code = "102"
            exit_code = "103"
            print(self.fun_exit_code.get_ifs_exit_code('103'))
            # print("{}".format(e))
            # self.logger.error(self.fun_exit_code.get_ifs_exit_code('102'))
            # self.logger.error(e)
            # status = 2
            # assert status in [CsstIFSStatus.PERFECT, CsstIFSStatus.WARNING]
        finally:
            return exit_code

    def config_ifs_rss_env(self):
        # /L1Pipeline/test_shao/test_data/ this dir is cdrs dir
        # self.config.set_ifs_config("path_RSSlog",
        #                            "/L1Pipeline/integration/ifs/csst_ifs_rss/proc_data/path_RSSlog.txt")
        # self.config.set_ifs_config("dir_rss_proc", "/L1Pipeline/integration/ifs/csst_ifs_rss/proc_data/")
        # self.config.set_ifs_config("dir_aux", "/L1Pipeline/integration/ifs/csst_ifs_rss/cal_data/")
        # self._config_ifs_rss_env_crds()
        # # self.config.set_ifs_config("path_l0_rss", self.dm.get_data_path_l0_sci(self.config.get_ifs_config("obsid")))
        # path_list = self.get_all_file_path("/L1Pipeline/integration/ifs/csst_ifs_rss/raw_data/")
        # self.config.set_ifs_config("path_l0_rss", path_list)
        #
        # self.config.set_ifs_config("path_l1_wcs_output",
        #                            "/L1Pipeline/test_shao/test_data/ifs/csst_ifs_wcs/temp_for_cube")

        self.config.set_ifs_config(
            "path_RSSlog",
            "/CSST_test/l1_all/workspace/test_data/ifs/sim/L0/IFS_simData_2023-06-26/proc_data/path_RSSlog.txt")
        # self.config.set_ifs_config(
        #     "dir_rss_proc", "/CSST_test/l1_all/workspace/test_data/ifs/sim/L0/IFS_simData_2023-06-26/proc_data/")
        self.config.set_ifs_config(
            "dir_rss_proc", "/datapool/CSST_PIPELINE/workspace/temp_data/ifs/sim/L1/sim_ver230725/proc_l1_rss/")
        self.config.set_ifs_config(
            "dir_aux",
            "/CSST_test/l1_all/workspace/test_data/ifs/sim/L0/IFS_CRDS_20230725/")
        self._config_ifs_rss_env_crds()
        # self.config.set_ifs_config("path_l0_rss", self.dm.get_data_path_l0_sci(self.config.get_ifs_config("obsid")))
        path_list = self.get_all_file_path(
            "/CSST_test/l1_all/workspace/test_data/ifs/sim/L0/IFS_simData_2023-07-25/sky_Data_temp/")
        self.config.set_ifs_config("path_l0_rss", path_list)

        self.config.set_ifs_config(
            "path_l1_wcs_output",
            "/CSST_test/l1_all/workspace/test_data/ifs/sim/L0/IFS_simData_2023-07-25/temp_for_cube")

        return

    @staticmethod
    def get_all_file_path(dir_temp):
        path_list = list()
        for root, dirs, names in os.walk(dir_temp):
            for filename in names:
                path_list.append(os.path.join(root, filename))
        return path_list

    @staticmethod
    def get_file_path_include_keywords(dir_temp, keywords):
        path_list = list()
        for root, dirs, names in os.walk(dir_temp):
            for filename in names:
                if keywords in filename:
                    path_list.append(os.path.join(root, filename))
        return path_list

    def _config_ifs_rss_env_crds(self):

        path = os.path.join(self.config.get_ifs_config("dir_aux"), self.dm.get_data_name_rss_bias_b())
        self.config.set_ifs_config("path_rss_biasm_b", path)
        path = os.path.join(self.config.get_ifs_config("dir_aux"), self.dm.get_data_name_rss_bias_r())
        self.config.set_ifs_config("path_rss_biasm_r", path)

        path = os.path.join(self.config.get_ifs_config("dir_aux"), self.dm.get_data_name_rss_flat_b())
        self.config.set_ifs_config("path_rss_flatm_b", path)
        path = os.path.join(self.config.get_ifs_config("dir_aux"), self.dm.get_data_name_rss_flat_r())
        self.config.set_ifs_config("path_rss_flatm_r", path)

        self.config.set_ifs_config("path_rss_dark_b", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_dark_b())
        self.config.set_ifs_config("path_rss_dark_r", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_dark_r())

        self.config.set_ifs_config("path_rss_flatnorm_b", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_flatnorm_b())
        self.config.set_ifs_config("path_rss_flatnorm_r", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_flatnorm_r())

        self.config.set_ifs_config("path_rss_trace_b", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_trace_b())
        self.config.set_ifs_config("path_rss_trace_r", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_trace_r())

        self.config.set_ifs_config("path_rss_ptow_b", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_ptow_b())
        self.config.set_ifs_config("path_rss_ptow_r", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_ptow_r())

        self.config.set_ifs_config("path_rss_starfile_b", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_starfile_b())
        self.config.set_ifs_config("path_rss_starfile_r", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_starfile_r())

        self.config.set_ifs_config("path_rss_arclab_b", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_arclab_b())
        self.config.set_ifs_config("path_rss_arclab_r", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_arclab_r())

        self.config.set_ifs_config("path_rss_starlab", self.config.get_ifs_config(
            "dir_aux") + self.dm.get_data_name_rss_starlab())
        return

    def config_ifs_cube_env(self):
        # self.config.set_ifs_config("dir_tmp",
        # "/nfsdata/users/csstpipeline/L1Pipeline/integration/ifs/csst_ifs_cube/aimdir")
        self.config.set_ifs_config("objid", "NGC6397")
        # self.config.set_ifs_config("path_l0_cube", self.dm.get_data_path_l1_sci(self.config.get_ifs_config("obsid")))

        # hdir = '/nfsdata/users/csstpipeline/L1Pipeline/integration/ifs/csst_ifs_cube/test_file/'
        # aimdir = '/nfsdata/users/csstpipeline/L1Pipeline/integration/ifs/csst_ifs_cube/aimdir/'
        target = 'NGC6397'
        hdir = '/nfsdata/users/csstpipeline/L1Pipeline/integration/ifs/csst_ifs_cube/test_file/'
        aimdir = '/nfsdata/users/csstpipeline/L1Pipeline/integration/ifs/csst_ifs_cube/aimdir/'
        softver = 'R7201'
        ver = 1
        lamr = hdir + "CSST_IFS_LAMP_MASTER_20220610_R_L1_R7201_bew_____.fits"
        lamb = hdir + "CSST_IFS_LAMP_MASTER_20220610_B_L1_R7201_bew_____.fits"
        self.config.set_ifs_config('objid', target)
        self.config.set_ifs_config('hdir', hdir)
        self.config.set_ifs_config('aimdir', aimdir)
        self.config.set_ifs_config('softver', softver)
        self.config.set_ifs_config('ver', ver)
        self.config.set_ifs_config('lamr', lamr)
        self.config.set_ifs_config('lamb', lamb)
        return
