"""
Identifier:     KSC-SJ6-csst_ifs_common/config.py
Name:           config.py
Description:    CSST IFS CONFIG
Author:         Wei Chen
"""

import os
import threading
from .ifs_status import CsstIFSStatus


class IFSConfig(object):
    """
    IFS Config as public parameters.
    """
    _instance_lock = threading.Lock()

    def __init__(self):
        self._set_ifs_config_init()

    def __new__(cls, *args, **kwargs):
        if not hasattr(IFSConfig, "_instance"):
            with IFSConfig._instance_lock:
                if not hasattr(IFSConfig, "_instance"):
                    IFSConfig._instance = object.__new__(cls)
                    cls.config_dict = dict()
                    cls.public_variable_dict = dict()
        return IFSConfig._instance

    def _set_ifs_config_init(self):
        local_path = os.getcwd()
        config_dict = {
            "dir_l0": ".",
            "dir_l1": ".",
            "dir_log": ".",
            "dir_rss": ".",
            "dir_cube": ".",
            "dir_local": local_path,
            "dir_rss_proc": "/L1Pipeline/integration/ifs/csst_ifs_rss/proc_data/"
        }
        if self.config_dict == {}:
            self.config_dict = config_dict

    def get_ifs_config(self, ifs_config_key):
        """
            get ifs config.

            Parameters
            ----------
            ifs_config_key : str
                The string of dict key

            Returns
            -------
            dict_value : string
                The string of dict_value.
        """
        if ifs_config_key in self.config_dict:
            ifs_config_value = self.config_dict[ifs_config_key]
            return ifs_config_value
        else:
            print("Error: key "+ifs_config_key+" not exist")
            status = 2
            assert status in [CsstIFSStatus.PERFECT, CsstIFSStatus.WARNING]

    def set_ifs_config(self, ifs_config_key, ifs_config_value):
        """
            get ifs config.

            Parameters
            ----------
            ifs_config_key : str
                The string of dict key

            ifs_config_value : anytype
                The string of dict value

            Returns
            -------
            None
        """
        # if ifs_config_key in self.config_dict:
        #     print("Warning: key "+ifs_config_key+" has exist, overwrite!")
        #     status = 1
        #     assert status in [CsstIFSStatus.PERFECT, CsstIFSStatus.WARNING]
        self.config_dict[ifs_config_key] = ifs_config_value
