"""
Identifier:     KSC-SJ6-csst_ifs_common/exit_code_list.py
Name:           exit_code_list.py
Description:    CSST IFS Exit Code List
Author:         Wei Chen
"""

import threading


class IFSExitCode(object):
    """
    IFS Exit Code as public.
    """
    _instance_lock = threading.Lock()

    def __init__(self):
        self.config_dict = {}
        self._set_ifs_exit_code_init()

    def __new__(cls, *args, **kwargs):
        if not hasattr(IFSExitCode, "_instance"):
            with IFSExitCode._instance_lock:
                if not hasattr(IFSExitCode, "_instance"):
                    IFSExitCode._instance = object.__new__(cls)
        return IFSExitCode._instance

    # modify exit code here!
    def _set_ifs_exit_code_init(self):
        config_dict = {
            "100": "l1 normal exit",
            "101": "l1 Env Set Error",
            "102": "Not found DFS system",
            "103": "CSST Dummy DFS system Initialize",
            "199": "l1 error exit",
            "200": "rss normal exit",
            "201": "rss error exit",
            "300": "cube normal exit",
            "301": "cube error exit",
            "400": "qc normal exit",
            "401": "qc error exit",
        }
        self.config_dict = config_dict

    def get_ifs_exit_code(self, ifs_exit_code_key):
        """
            get ifs config.

            Parameters
            ----------
            ifs_exit_code_key : str
                The string of dict key

            Returns
            -------
            dict_value : string
                The exit_code of program status.
            """
        if ifs_exit_code_key in self.config_dict:
            ifs_exit_code_value = self.config_dict[ifs_exit_code_key]
            return ifs_exit_code_value
        else:
            print("Error: key "+ifs_exit_code_key+" not exist")

    def set_ifs_exit_code(self, ifs_exit_code_key, ifs_exit_code_value):
        """
            get ifs config.

            Parameters
            ----------
            ifs_exit_code_key : str
                The string of dict key

            ifs_exit_code_value : str
                The string of dict value

            Returns
            -------
            None
            """
        if ifs_exit_code_key in self.config_dict:
            print("Warning: key "+ifs_exit_code_key+" has existed, overwrite!")

        self.config_dict[ifs_exit_code_key] = ifs_exit_code_value
